#!/bin/sh
ts_check_tun=30

. /opt/kelvpn/sbin/kelvpn_func.sh

. /opt/kelvpn/share/KelVPNCheck.conf

if [ "$KELVPN_CONNECTED" = "false" ]; then
    log_it_notice "VPN connection is disabled in config (KELVPN_CONNECTED=false). Exiting..."
    exit 0
fi

cli_connect_params="-C"
if [ "$KELVPN_MODE" = "hybrid" ]; then
    cli_connect_params="--notable $cli_connect_params"
fi

if [ -z "$KELVPN_SERVER" ]; then
    log_it_error "KELVPN_SERVER is not set in /opt/kelvpn/etc/KelVPNCheck.conf!"
    exit 1
fi

kelvpn_server="$KELVPN_SERVER"
echo "Connect params \"$cli_connect_params\""


PIDFILE="/tmp/KelVPNCheck.pid"

if [ -e $PIDFILE ]; then
    pid=`cat $PIDFILE`
    if ps $pid >/dev/null 2>/dev/null; then
	log_it_error "Already is running with pid $pid, can't run the second instance"
	exit 1
    else
	log_it_notice " PID \"$pid\" is not present is table. Removing pid file and continue the check'n'reconnect"
	rm $PIDFILE
    fi
fi
echo $$ > $PIDFILE

while true; do
    if /opt/kelvpn/sbin/kelvpn_check_tun.sh; then
	log_it_debug "Tunnel works and internet is present. Sleep $ts_check_tun"
	sleep $ts_check_tun
	continue;
    fi
    log_it "Bringing up VPN"

    servers=`timeout 20 /opt/kelvpn/bin/KelVPNCli -L | grep '|' | grep -F "$kelvpn_server" | awk -F '|' '{print $1}' | awk '{print $1}' | sort -R`

    for s in $servers; do
	kelvpn_service_restart
	sleep 3
	log_it "Trying to connect with server $s"
	/opt/kelvpn/sbin/kelvpn_route.sh init
	if timeout 20 /opt/kelvpn/bin/KelVPNCli $cli_connect_params $s >> $log_it_out; then
	    log_it_debug "KelVPNCli -C execution returned $?"
	    if ip link show tun0; then
		log_it "Tun is present"
	    else
		log_it_error "No tun, looks connection wasn't successful. Waiting for 3 sec and trying another server"
		#sleep 3
		continue
	    fi
	    log_it_notice "Connected to $s. Now lets check the internet connection itself"

	    if [ "$KELVPN_MODE" = "hybrid" ]; then
		/opt/kelvpn/sbin/kelvpn_hybrid.sh all add
		sed -i 's/nameserver .*/nameserver 8.8.8.8/'  /etc/resolv.conf
	    fi

	    if /opt/kelvpn/sbin/kelvpn_check_tun.sh; then
		log_it_notice "Connected!"
		if [ "$KELVPN_wifi1_MODE" = "full" ]; then
		    /opt/kelvpn/sbin/kelvpn_route.sh add
		fi
		break;
	    else
		log_it_error "Can't ping gateway ip address, lets try another server"
		if timeout 10 /opt/kelvpn/bin/KelVPNCli -D; then 
		    log_it_notice "Disconnected from $s"
		else
		    log_it_error "Failed to disconnect from $s"
		    continue;
		fi
	    fi
	else
	    echo "[ ] Failed to connect with $s, trying the next one" >> $log
	fi
    done
done
